@@ -9,7 +9,7 @@
  */
 define('oxguard/contacts/register_contacts', [
     'io.ox/core/extensions',
-    'oxguard/pgp/publickeys',
+    'oxguard/pgp/keyDetails',
     'settings!oxguard',
     'less!oxguard/style'
 ], function (ext, pubkeys, settings) {
@@ -21,11 +21,12 @@ define('oxguard/contacts/register_contacts', [
             //FIXME: this completely disables the point for apps other than settings and contacts (like mail called from sidepanel)
             if (!(baton.app && baton.app.cid)) return;
             if (!settings.get('advanced')) return;  //advanced view only
-            var list = (baton.data.email1 ? baton.data.email1 : '') + (baton.data.email2 ? (',' + baton.data.email2) : '') + (baton.data.email3 ? (',' + baton.data.email3) : '');
+            if (baton.data && baton.data.distribution_list) return;  // Not listing for distribution lists
+            //var list = (baton.data.email1 ? baton.data.email1 : '') + (baton.data.email2 ? (',' + baton.data.email2) : '') + (baton.data.email3 ? (',' + baton.data.email3) : '');
             var newfield = $('<fieldset class="block" data-block="pgp">');
             var location = $(this).find('article.clearfix');
             if (location[0] !== undefined) {
-                $(location[0]).append(newfield.append(pubkeys.listPublic(baton.app.cid, list)));
+                $(location[0]).append(newfield.append(pubkeys.listPublic(baton.app.cid, baton.data.folder_id, baton.data.id)));
             }
 
         }
