@@ -16,10 +16,6 @@ define('oxguard/core/errorHandler', [
     function showError (json) {
         if (json[0] !== undefined) json = json[0];
         if (json.error) {
-            if (json.error_desc) {
-                notify.yell('error', json.error);
-                return;
-            }
             notify.yell('error', json.error);
         }
     }
