@@ -11,7 +11,7 @@ define('oxguard/core/og_http', [
 ], function () {
     'use strict';
 
-    function doPost (url, params, data) {
+    function doPost (url, params, data, json) {
         var def = $.Deferred();
         params = params + '&session=' + ox.session;
         if (data === null || data === undefined) data = {};
@@ -19,10 +19,13 @@ define('oxguard/core/og_http', [
         $.ajax({
             url: url + params,
             type:'POST',
-            dataType: 'json',
-            data: JSON.stringify(data),
-            contentType:'application/json; charset=utf-8;',
+            dataType: json ? 'json' : 'text',
+            data: (json ? JSON.stringify(data) : data),
+            contentType: (json ? 'application/json; charset=utf-8;' : 'application/x-www-form-urlencoded'),
             success: function (rdata) {
+                if (!json && rdata && rdata.indexOf('{') === 0) {  // If json response instead of text, parse the json
+                    rdata = JSON.parse(rdata);
+                }
                 def.resolve (rdata);
                 if ((_.now() - t0) > 1000) {
                     require (['oxguard/core/log'], function (log) {
@@ -69,8 +72,18 @@ define('oxguard/core/og_http', [
         return (def);
     }
 
-    // Look for passwords in outgoing data.  If able, encrypt
+    // Post JSON data
     function post (url, params, data) {
+        return postAction (url, params, data, true);
+    }
+
+    // Post using x-www-form-urlencoded
+    function simplePost (url, params, data) {
+        return postAction (url, params, data, false);
+    }
+
+    // Look for passwords in outgoing data.  If able, encrypt
+    function postAction (url, params, data, json) {
         var def = $.Deferred();
         require (['oxguard/crypto/encr'], function (encr) {
             if (window.oxguarddata && window.oxguarddata.pubKey !== undefined && data !== undefined) {
@@ -102,7 +115,7 @@ define('oxguard/core/og_http', [
                     }
                 }
             }
-            doPost (url, params, data)
+            doPost (url, params, data, json)
             .done (function (e) {
                 def.resolve(e);
             })
@@ -146,6 +159,7 @@ define('oxguard/core/og_http', [
 
     return {
         post: post,
+        simplePost: simplePost,
         get: get,
         put: doPut
     };
