@@ -8,19 +8,22 @@
  * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/core/passwords', [
-    'gettext!oxguard'
+    'gettext!oxguard',
+    'less!oxguard/core/style'
 ], function (gt) {
     'use strict';
 
     // Compare two el1 to el2 values whenever el1 changes.  If hint
     // has value, then color and text if different
     function passwordCompare (el1, el2, hint) {
-        $(el1).on('input', function () {
-            $(el1).removeClass('oxguard_badpass');
-            if ($(el1).length >= 1) {
-                el2.removeClass('oxguard_warnpass').removeClass('oxguard_badpass').removeClass('oxguard_goodpass');  // remove color markup of the first password box
-                if ($(el1).val() !== $(el2).val()) {
-                    $(el1).addClass('oxguard_badpass');
+        var el1ToCompare = el1.getForCompare ? el1.getForCompare() : el1;  // Check if password View
+        var el2ToCompare = el2.getForCompare ? el2.getForCompare() : el2;
+        $(el1ToCompare).on('input', function () {
+            $(el1ToCompare).removeClass('oxguard_badpass');
+            if ($(el1ToCompare).length >= 1) {
+                el2ToCompare.removeClass('oxguard_warnpass').removeClass('oxguard_badpass').removeClass('oxguard_goodpass');  // remove color markup of the first password box
+                if ($(el1ToCompare).val() !== $(el2ToCompare).val()) {
+                    $(el1ToCompare).addClass('oxguard_badpass');
                     if (hint !== undefined) {
                         hint.removeClass('oxguard_hint_bad').removeClass('oxguard_hint_good').removeClass('oxguard_hint_warn');
                         hint.addClass('oxguard_hint_bad').text(gt('Passwords not equal'));
@@ -36,7 +39,8 @@ define('oxguard/core/passwords', [
 
     // Add event to check password strength of element
     function passwordCheck(element, hint) {
-        $(element).on('input', function () {
+        var checkElement = element.getForCompare ? element.getForCompare() : element;
+        $(checkElement).on('input', function () {
             check.call(this, hint);
         });
     }
