@@ -16,14 +16,14 @@ define('oxguard/files/downloader', [
     {
         var file_options = { params: {
                 cryptoAction: 'Decrypt',
-                cryptoAuth: auth
+                cryptoAuth: auth,
+                session: encodeURIComponent(ox.session)
             } };
         var selection = [].concat(baton.data);
         baton.collection.models.map(function (file) {
-            if (file.get('filename') && (file.get('filename').indexOf('.pgp') > 0 || (file.get('source') === 'guard') || (file.get('meta') && (file.get('meta').Encrypted === true)))) {// Make sure OxGuard file
+            if (file.get('filename') && (/(\.pgp)$/i.test(file.get('filename')) || (file.get('source') === 'guard') || (file.get('meta') && (file.get('meta').Encrypted === true)))) {// Make sure OxGuard file
                 file.set('file_options', file_options);
                 file.set('source', 'guardDrive');
-                file.set('shareable', false);
             }
         });
         ox.load(['io.ox/core/viewer/main']).done(function (Viewer) {
