@@ -16,8 +16,7 @@ define('oxguard/files/register', [
     'io.ox/core/dropzone',
     'oxguard/auth',
     'gettext!oxguard',
-    'io.ox/core/extPatterns/links',
-    'less!oxguard/style'
+    'io.ox/core/extPatterns/links'
 ], function (ext, capabilities, oxguard, folderAPI, util, dropzone, auth_core, gt, links) {
 
     'use strict';
@@ -33,7 +32,7 @@ define('oxguard/files/register', [
                     var download = $('<a href="#" class="btn btn-default">' + gt('Download decrypted') + '</a>');
                     download.click(function (ev) {
                         ev.preventDefault();
-                        auth_core.authorize().then(function (data) {
+                        auth_core.authorize(baton).then(function (data) {
                             require (['oxguard/files/downloader'], function (downloader) {
                                 metrics('guard', 'decrypt & download');
                                 downloader.viewFile(baton, 'download', data);
@@ -94,6 +93,29 @@ define('oxguard/files/register', [
         ref: 'oxguard/remencrypt'
     }));
 
+    // Context menu
+
+    ext.point('io.ox/core/file/contextmenu/default/items').extend(
+        {
+            id: 'encrypt',
+            index: 1450,
+            ref: 'oxguard/encrypt',
+            section: '25',
+            label: gt('Encrypt')
+        }
+    );
+
+    ext.point('io.ox/core/file/contextmenu/default/items').extend(
+
+        {
+            id: 'decrypt',
+            index: 1450,
+            ref: 'oxguard/remencrypt',
+            section: '25',
+            label: gt('Remove encryption')
+        }
+    );
+
     // Change send copy to handle Guard emails
     ext.point('io.ox/files/actions/send').extend({
         id: 'og_stop_send',
@@ -122,6 +144,50 @@ define('oxguard/files/register', [
     //////////////  Viewer
     /// Links
 
+    // Extension to handle direct link files. Will not be used for opening list of files with selection
+    ext.point('io.ox/core/viewer/main').extend({
+        id: 'guardAuthCheck',
+        index: 10,
+        perform: function (baton) {
+            var def = $.Deferred();
+            if (baton.data.selection) {
+                return def.resolve();  // Not handling here
+            }
+            var files = baton.data.files;
+            if (!files || files.length === 0) {
+                return def.resolve();
+            }
+            var file = files[0];
+            if (isOGFile(file)) {
+                auth_core.authorize(file, undefined, true)
+                .then (function (auth) {
+                    var file_options = { params: {
+                        cryptoAction: 'Decrypt',
+                        cryptoAuth: auth,
+                        session: ox.session
+                    } };
+                    // fix for #58378
+                    for (var i = 0; i < baton.data.fileList.length; i++) {
+                        // fix for #58617
+                        if (baton.data.fileList[i] instanceof Backbone.Model) {
+                            baton.data.fileList[i].set('file_options', file_options);
+                            baton.data.fileList[i].set('source', 'guardDrive');
+
+                        } else {
+                            baton.data.fileList[i].file_options = file_options;
+                            baton.data.fileList[i].source = 'guardDrive';
+                        }
+                    }
+
+                    def.resolve(baton);
+                }, def.reject);
+                return def;
+            } else {
+                return def.resolve();
+            }
+        }
+    });
+
     ext.point('io.ox/core/viewer/actions/toolbar/popoutstandalone').extend({
         id: 'popoutstandalone_guardcheck',
         index: 1,
@@ -220,8 +286,8 @@ define('oxguard/files/register', [
 
     // Upload new encrypted file
     new links.Action('io.ox/files/actions/uploadEncrypt', {
+        capabilities: 'guard-drive',
         requires: function (e) {
-            if (util.isMailvelope ()) return false;
             return e.baton.app.folder.getData().then(function (data) {
                 //hide for virtual folders (other files root, public files root)
                 var virtual = _.contains(['14', '15'], data.id);
@@ -239,7 +305,6 @@ define('oxguard/files/register', [
 
     new links.Action('oxguard/downloadEncrypted', {
         requires: function (e) {
-            if (util.isMailvelope ()) return false;
             if (e.baton.data) {
                 if (isOGFile(e.baton.data)) {
                     return (true);
@@ -273,6 +338,52 @@ define('oxguard/files/register', [
         }
     });
 
+    // Disable publication of Guard files
+    ext.point('io.ox/files/actions/getalink').extend({
+        index: 10,
+        id: 'guardCheck',
+        requires: function (e) {
+            if (isOGFile(e.baton.data)) {
+                e.stopPropagation();
+                return false;
+            }
+        }
+    });
+
+    ext.point('io.ox/files/actions/invite').extend({
+        capabilities: 'guard-drive',
+        index: 10,
+        id: 'guardCheck',
+        requires: function () {
+            return false;
+        },
+        action: function (baton) {
+            // If OG file, needs authentication to change invite permissions
+            if (isOGFile(baton.data)) {
+                if (baton.data && baton.data.validated) {
+                    baton.data.validated = false;
+                    return;  // already authorized
+                }
+                baton.stopPropagation();  // Terminate
+                var loc = this;
+                require(['oxguard/auth', 'io.ox/core/extPatterns/actions'], function (auth_core, actions) {
+                    auth_core.authorize(baton, gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
+                    .done(function () {
+                        if (baton.data) baton.data.validated = true;
+                        baton.resumePropagation();
+                        actions.invoke('io.ox/files/actions/invite', loc, baton);  // OK, authorized, call the extension again
+                    })
+                    .fail(function () {
+                        baton.stopPropagation();
+                        window.setTimeout(function () {
+                            baton.resumePropagation();
+                        }, 500);
+                    });
+                });
+            }
+        }
+    });
+
     // Replacement popout for Guard
     new links.Action('oxguard/popoutstandalone', {
         requires: function (e) {
@@ -306,8 +417,8 @@ define('oxguard/files/register', [
     });
 
     new links.Action('oxguard/sendcopy', {
+        capabilities: 'guard-drive',
         requires: function (e) {
-            if (util.isMailvelope ()) return false;
             //all files must be encrypted
             var toCheck = e.baton.models === null ? e.baton.model : e.baton.models;
             return e.collection.has('some') && util.hasEncrypted(toCheck) && util.isNotAttachment(toCheck) && capabilities.has('webmail');
@@ -320,16 +431,39 @@ define('oxguard/files/register', [
         }
     });
 
+    function okToDecrypt (e, data) {
+        var virtual = _.contains(['14', '15'], data.id);
+        return e.collection.has('some', 'modify', 'items') && util.encryptedOnly(e.baton.models) &&
+            folderAPI.can('create', data) && !virtual && !folderAPI.is('trash', data) &&
+            !folderAPI.isExternalFileStorage(data);
+    }
+
     new links.Action('oxguard/remencrypt', {
+        capabilities: 'guard-drive',
         requires: function (e) {
             //all files must be encrypted
-            var toCheck = e.baton.models === null ? e.baton.model : e.baton.models;
-            return e.collection.has('some') && util.encryptedOnly(toCheck) && util.isNotAttachment(toCheck);
+            if (e.collection.has('folders')) return false;
+            if (e.baton.app) {
+                return e.baton.app.folder.getData().then(function (data) {
+                    return okToDecrypt (e, data);
+                });
+            }
+            var folderId = _.isArray(e.baton.data) ? e.baton.data[0].folder_id : e.baton.data.folder_id;
+            if (folderId) {
+                return folderAPI.get(folderId).then(function (data) {
+                    return okToDecrypt (e, data);
+                });
+            }
+            return false;
         },
         multiple: function (list, baton) {
             ensureSetup().then(function () {
-                auth_core.authorize().then(function (auth) {
+                auth_core.authorize(baton).then(function (auth) {
+                    var warnShares = false;
                     for (var file in list) {
+                        if (list[file].object_permissions && list[file].object_permissions.length > 0) {
+                            warnShares = true;
+                        }
                         list[file].file_options = {
                             params: {
                                 cryptoAction: 'Decrypt',
@@ -337,30 +471,49 @@ define('oxguard/files/register', [
                             }
                         };
                     }
-                    require(['io.ox/files/api'], function (fileApi) {
-                        fileApi.copy(list, list[0].folder_id, false)
-                        .then(function (e) {
-                            if (e.length == list.length) {
-                                for (var i in list) {
-                                    if (e[i].data) {
-                                        fileApi.remove([list[i]], true);
-                                    }
-                                }
-                            } else {
-                                if (_.isString(e)) {
-                                    require (['io.ox/core/notifications'], function (notify) {
-                                        notify.yell('error', e);
-                                    });
-                                }
-                            }
+                    if (warnShares) {
+                        require(['io.ox/core/tk/dialogs'], function (dialogs) {
+                            var dialog = new dialogs.ModalDialog();
+                            dialog.text(gt('Shares found'))
+                                .append($('<p>').text(gt('You are removing encryption from file(s) that have shares. These shares will no longer work once the file is decrypted.  You can add the shares back once the file is decrypted.')))
+                                .append($('<p>').text(gt('Do you wish to proceed?')))
+                                .addPrimaryButton('decrypt', gt('Remove encryption'), 'decrypt')
+                                .addButton('cancel', gt('Cancel'), 'cancel')
+                                .on('decrypt', function () {
+                                    doRemEncryptFile(list);
+                                })
+                                .show();
                         });
-                    });
+                    } else {
+                        doRemEncryptFile(list);
+                    }
+                    baton.openedBy = 'io.ox/files';
                 });
-                baton.openedBy = 'io.ox/files';
             });
         }
     });
 
+    function doRemEncryptFile(list) {
+        require(['io.ox/files/api'], function (fileApi) {
+            fileApi.copy(list, list[0].folder_id, false)
+            .then(function (e) {
+                if (e.length == list.length) {
+                    for (var i in list) {
+                        if (e[i].data) {
+                            fileApi.remove([list[i]], true);
+                        }
+                    }
+                } else {
+                    if (_.isString(e)) {
+                        require (['io.ox/core/notifications'], function (notify) {
+                            notify.yell('error', e);
+                        });
+                    }
+                }
+            });
+        });
+    }
+
     new links.Action('oxguard/open', {
         requires: function (e) {
             if (e.baton.data) {
@@ -371,10 +524,11 @@ define('oxguard/files/register', [
             return (false);
         },
         multiple: function (list) {
-            auth_core.authorize().then(function (auth) {
+            auth_core.authorize(list).then(function (auth) {
                 var params = {
                     'cryptoAction': 'Decrypt',
-                    'cryptoAuth': auth
+                    'cryptoAuth': auth,
+                    'session': ox.session
                 };
                 require (['io.ox/files/api'], function (fileApi) {
                     _(list).each(function (file) {
@@ -394,12 +548,13 @@ define('oxguard/files/register', [
             return e.collection.has('some') && util.encryptedOnly(toCheck) && util.isNotAttachment(toCheck);
         },
         multiple: function (list) {
-            auth_core.authorize().then(function (auth) {
+            auth_core.authorize(list).then(function (auth) {
                 for (var file in list) {
                     list[file].filename = (list[file].filename ? list[file].filename.replace('.pgp', '') : '');
                     list[file].params = {
                         'cryptoAction': 'Decrypt',
-                        'cryptoAuth': auth
+                        'cryptoAuth': auth,
+                        'session': ox.session
                     };
                     list[file].cache = false;
                 }
@@ -438,17 +593,13 @@ define('oxguard/files/register', [
                     file.set('file_options', {});
                 });
             });
-            // Blank insert for 2.6   Plan to add icon in next release
-            $(this).append('<a href="#" style="padding: 0 0 0 1px; min-width: 1px;"></a>');
-            //$(this).append('<a href="#" style="padding: 0 0 0 16px; min-width: 1px;"><i class="fa fa-lock" aria-hidden="true"></i></a>');
-            $(this).addClass('lockLeft');
         }
     });
 
     // Handle viewing Guard file
     function viewFile (baton) {
         if (isOGFile (baton.data)) {
-            auth_core.authorize().then(function (auth) {
+            auth_core.authorize(baton).then(function (auth) {
                 require (['oxguard/files/downloader'], function (downloader) {
                     downloader.viewFile(baton, 'view', auth);
                 });
@@ -459,7 +610,7 @@ define('oxguard/files/register', [
     ext.point('io.ox/files/dropzone').extend({
         id: 'dragDrop',
         getDropZones: function (baton) {
-            if (util.isMailvelope()) return;
+            if (!capabilities.has('guard-drive')) return;
             var app = baton.app,
                 zone2 = new dropzone.Inplace({
                     caption: gt('Drop files here to encrypt')
@@ -493,7 +644,7 @@ define('oxguard/files/register', [
             var def = $.Deferred();
             require (['oxguard/core/createKeys'], function (keys) {
                 oxguard.metrics('drive', 'create-keys');
-                keys.createKeysWizard(true)
+                keys.createKeysWizard()
                 .then(def.resolve, def.reject);
             });
             return def;
@@ -512,8 +663,8 @@ define('oxguard/files/register', [
     }
 
     new links.Action('oxguard/encrypt', {
+        capabilities: 'guard-drive',
         requires: function (e) {
-            if (util.isMailvelope ()) return false;
             //all files must be unencrypted
             if (e.collection.has('folders')) return false;
             if (e.baton.app) {
@@ -522,42 +673,68 @@ define('oxguard/files/register', [
                 });
             }
             var folderId = _.isArray(e.baton.data) ? e.baton.data[0].folder_id : e.baton.data.folder_id;
-            return folderAPI.get(folderId).then(function (data) {
-                return okToEncrypt (e, data);
-            });
+            if (folderId) {
+                return folderAPI.get(folderId).then(function (data) {
+                    return okToEncrypt (e, data);
+                });
+            }
+            return false;
         },
         multiple: function (list) {
             ensureSetup().then(function () {
+                var warnShares = false;
                 for (var file in list) {
+                    if (list[file].object_permissions && list[file].object_permissions.length > 0) {
+                        warnShares = true;
+                    }
                     list[file].file_options = {
                         params: {
                             cryptoAction: 'Encrypt'
                         }
                     };
                 }
-                require(['io.ox/files/api'], function (fileApi) {
-                    fileApi.copy(list, list[0].folder_id, false)
-                    .then(function (e) {
-                        if (e.length == list.length) {
-                            for (var i in list) {
-                                if (e[i].data) {
-                                    fileApi.remove([list[i]], true);
-                                }
-                            }
-                        } else {
-                            if (_.isString(e)) {
-                                require (['io.ox/core/notifications'], function (notify) {
-                                    notify.yell('error', e);
-                                });
-                            }
-                        }
+                if (warnShares) {
+                    require(['io.ox/core/tk/dialogs'], function (dialogs) {
+                        var dialog = new dialogs.ModalDialog();
+                        dialog.text(gt('Shares found'))
+                            .append($('<p>').text(gt('There are shares associated with the file(s) you are going to encrypt. These shares will no longer work once the file is encrypted.  You can add the shares back once the file is encrypted.')))
+                            .append($('<p>').text(gt('Do you wish to proceed?')))
+                            .addPrimaryButton('encrypt', gt('Encrypt'), 'encrypt')
+                            .addButton('cancel', gt('Cancel'), 'cancel')
+                            .on('encrypt', function () {
+                                doEncryptFile(list);
+                            })
+                            .show();
                     });
-                });
+                } else {
+                    doEncryptFile(list);
+                }
             });
 
         }
     });
 
+    function doEncryptFile(list) {
+        require(['io.ox/files/api'], function (fileApi) {
+            fileApi.copy(list, list[0].folder_id, false)
+            .then(function (e) {
+                if (e.length == list.length) {
+                    for (var i in list) {
+                        if (e[i].data) {
+                            fileApi.remove([list[i]], true);
+                        }
+                    }
+                } else {
+                    if (_.isString(e)) {
+                        require (['io.ox/core/notifications'], function (notify) {
+                            notify.yell('error', e);
+                        });
+                    }
+                }
+            });
+        });
+    }
+
     /////////////////  Util, prompts, etc
 
     function metrics (target, action) {
@@ -582,11 +759,11 @@ define('oxguard/files/register', [
     */
     function isOGFile(file) {
         try {
-            if (file.filename === null) return (false);
+            if (!file.filename) return (false);
             if (file.meta !== undefined) {
                 if (file.meta.Encrypted) return (true);
             }
-            if ((file.filename.indexOf('.grd') > 0) || (file.filename.indexOf('.grd2') > 0) || (file.filename.indexOf('.pgp') > 0)) return (true);
+            if (/(\.pgp)$/i.test(file.filename)) return true;
         } catch (e) {
             return (false);
         }
