@@ -1,7 +1,6 @@
 define('oxguard/files/util', [
-    'oxguard/util',
-    'settings!oxguard'
-], function (coreUtil, settings) {
+    'oxguard/util'
+], function (coreUtil) {
     'use strict';
 
     var util = _.extend({}, coreUtil);
@@ -35,9 +34,5 @@ define('oxguard/files/util', [
         } else return (list.get('pgpFormat') === undefined);
     };
 
-    util.isMailvelope = function isMailvelope() {
-        return (settings.get('cryptoProvider') === 'mailvelope');
-    };
-
     return util;
 });
