@@ -4,10 +4,19 @@ define('oxguard/mail/maillist', [
 ], function (extensions, ext) {
     'use strict';
 
-    var lockclass = 'icon-lock icon-2x fa fa-lock fa-2x oxguard_icon_fa';
-    var newlockclass = 'icon-lock icon-2x fa fa-lock encrypted';
     var initialized = false;
 
+    // Override default icon extension for encrypted icons
+    extensions.pgp.encrypted = function (baton) {
+        if (!/^multipart\/encrypted/.test(baton.data.content_type) &&
+                !(baton.model.get('security_info') && baton.model.get('security_info').encrypted) &&
+                !(baton.model.get('security') && baton.model.get('security').decrypted)) return;
+
+        this.append(
+            $('<i class="fa fa-lock encrypted" aria-hidden="true">')
+        );
+    };
+
     // Changed selection.  Null out the guard current data
     function change () {
         window.oxguarddata.current = null;
@@ -58,6 +67,15 @@ define('oxguard/mail/maillist', [
                 extensions.paperClip.call(this, baton);
                 return;
             }
+            // Encrypted, we don't know if attachments
+            if (baton.model.get('security_info') && baton.model.get('security_info').encrypted) {
+                if (!(baton.model.get('security') && baton.model.get('security').decrypted)) {
+                    return;
+                }
+            }
+            if (baton.model.get('content_type') === 'multipart/encrypted') {
+                return;
+            }
             var headers = baton.model.get('headers');
             if (headers === undefined) {
                 extensions.paperClip.call(this, baton);
@@ -69,10 +87,7 @@ define('oxguard/mail/maillist', [
             }
             /// PGP Components
             // Check if decoded
-            if (baton.model.get('PGPDecoded') === true) {
-                if (baton.model.get('attachments')[0].pgpFormat === 'pgpinline') {
-                    this.append($('<i class="' + newlockclass + '" aria-hidden="true">'));
-                }
+            if (baton.model.get('security') && baton.model.get('security').decrypted) {
                 if (baton.model.get('attachment') === true) {
                     extensions.paperClip.call(this, baton);
                 } else {
@@ -80,64 +95,10 @@ define('oxguard/mail/maillist', [
                 }
                 return;
             }
-            // Check if not yet decoded PGP
-            for (var i = 0; i < attachments.length; i++) {// check for attachments
-                try {
-                    if (attachments[i].content_type !== null) {
-                        if (attachments[i].content_type.indexOf('text') > -1) {
-                            if (attachments[i].content !== null) {
-                                if (attachments[i].content.indexOf('----BEGIN PGP MESSAGE') > 0) { // Search for PGP Inline and draw lock
-                                    this.append($('<i class="' + newlockclass + '" aria-hidden="true">'));
-                                    extensions.paperClip.call(this, baton);
-                                    return;
-                                }
-                            }
-                        }
-                    }
-                } catch (e) {
-                    console.log('error getting content type of attachment ', e);
-                }
-            }
-            // Proprietary Guard components
-            if (headers['X-OxGuard-ID'] !== undefined) {
-                baton.data.og = true;
-                baton.model.set('og', true);
-                this.append($('<i class="' + lockclass + '" aria-hidden="true">'));
-
-                if (attachments === undefined) {
-                    return;
-                }
-                var hasattach = false;
-                for (var i = 0; i < attachments.length; i++) {// check for attachments
-                    if (attachments[i].disp !== 'inline') {
-                        if (attachments[i].filename.indexOf(headers['X-OxGuard-ID']) < 0) {
-                            if ((attachments[i].ogAttach === true) || (attachments[i].filename.indexOf('.grd') > 0)) // Screen for generated part attachments
-                                hasattach = true; // if not main body encr attachment
-                        }
-                    }
-                }
-                if (hasattach) {// If we have attachment, add icon
-                    extensions.paperClip.call(this, baton);
-                }
-            } else extensions.paperClip.call(this, baton);
+            extensions.paperClip.call(this, baton);  // Otherwise, call paperclip
         } catch (ex) {
             console.log('Problem checking list for OG email');
             console.log(ex);
         }
     }
-
-    ext.point('io.ox/mail/detail/header').extend({
-        id: 'OGHpaper-clip',
-        after: 'flag-picker',
-        draw: function (baton) {
-            if (baton.data.decoded === true) {
-                if (baton.data.attachments === undefined) return;
-                if (baton.data.attachments.length > 1) {// If we do have more than one attachment, add icon
-                    extensions.paperClip.call(this, baton);
-                }
-            } else extensions.paperClip.call(this, baton);
-        }
-    });
-
-    ext.point('io.ox/mail/detail/header').disable('paper-clip');
 });
