@@ -11,11 +11,11 @@
 define('oxguard/mail/options_new', [
     'oxguard/mail/oxguard_mail_compose_core',
     'oxguard/mail/util',
-    'settings!io.ox/mail',
     'oxguard/util',
-    'gettext!oxguard'
-], function (core, util, mailSettings, coreUtil, gt) {
-
+    'settings!oxguard',
+    'gettext!oxguard',
+    'less!oxguard/mail/style'
+], function (core, util, coreUtil, settings, gt) {
     'use strict';
 
     var lockclass = 'icon-lock icon-2x fa fa-lock fa-2x oxguard_lock';
@@ -69,23 +69,9 @@ define('oxguard/mail/options_new', [
         });
     }
 
-    /// Disable the recipient inputs and color the background
-    function lockReply (baton) {
-        var view = baton.view.$el;
-        view.find('.token-input').attr('disabled', 'disabled');
-        view.find('.token-input').addClass('og_disabled').click(notice);
-        view.find('.tokenfield').addClass('og_disabled').click(notice);
-    }
-
-    function notice () {
-        require (['io.ox/core/notifications'], function (notifications) {
-            notifications.yell('error', gt('Recipients cannot be added to this encrypted reply'));
-        });
-    }
-
     function getType(current) {
         if (current === null || current === undefined) {  // if no decoded data, then return default
-            if (window.oxguarddata.settings.inline === true) {
+            if (settings.get('defaultInline')) {
                 return ('inline');
             } else return ('mime');
         }
@@ -113,8 +99,8 @@ define('oxguard/mail/options_new', [
                 window.oxguarddata.draftfolder = settings.get('folder/drafts');
             });
         }
-        window.setTimeout (function () {
-            createlock(baton);
+        var mode = baton.model.get('mode');
+        ox.once('mail:' + mode + ':ready', function () {
             baton.model.dirty(false);
             // If this is a secure reply, then disable all of the options to make it plain text
             if ((window.oxguarddata.action === 'secureReply') || (window.oxguarddata.action === 'fileAttach') || (util.hasEncryptedAttachment(baton) > 0)) {
@@ -128,33 +114,29 @@ define('oxguard/mail/options_new', [
                 baton.model.set('encrypt', true);
                 if (window.oxguarddata.settings.oxguard === false || window.oxguarddata.settings.secureReply === true) {
                     baton.view.$el.find('#statuslock')
-                    .attr('class', lockclass)
-                    .click(false)
-                    .attr('title', gt('Reply must be encrypted'));
+                        .attr('class', lockclass)
+                        .click(false)
+                        .attr('title', gt('Reply must be encrypted'));
                     baton.view.$el.find('[data-name="encrypt"]').click(false);
                 }
-                if ((window.oxguarddata.action === 'secureReply') && (window.oxguarddata.settings.oxguard === false)) {
-                    // If secure reply, and does not have OG, only allow reply to orig
-                    window.setTimeout (function () {
-                        lockReply (baton);
-                    }, 500);
-                }
                 window.oxguarddata.action = null;
             }
             var headers = baton.model.get('headers');
             if (headers && (headers['X-OxGuard-Sign'] === 'true')) {
                 baton.model.set('PGPSignature', true);
             }
-        }, 200);
+        });
+
+        createlock(baton);
 
         if (baton.model.get('newmail') === true && coreUtil.hasGuardMailCapability()) {  // New email doesn't have recips yet.  Check to see if there are defaults
             // If default is to use guard, go ahead and lock
-            if (window.oxguarddata.settings.pgpdefault || mailSettings.get('defaultEncrypt')) {
+            if (settings.get('defaultEncrypted')) {
                 baton.model.set('encrypt', true);
                 core.lock(baton);
             } else baton.model.set('encrypt', false);
-            if (window.oxguarddata.settings.inline === true) {
-                if (window.oxguarddata.settings.pgpdefault) {
+            if (settings.get('defaultInline')) {
+                if (settings.get('defaultEncrypted')) {
                     baton.model.set('PGPFormat', 'inline');
                     warnHTML(baton);
                 } else {
@@ -163,7 +145,7 @@ define('oxguard/mail/options_new', [
             } else baton.model.set('PGPFormat', 'mime');
             baton.model.unset('newmail');
 
-            if (window.oxguarddata.settings.pgpsign) {
+            if (settings.get('defaultSign')) {
                 baton.model.set('PGPSignature', true);
             }
         }
