@@ -13,37 +13,105 @@ define('oxguard/mail/oxguard_mail_compose_core', [
     'io.ox/core/notifications',
     'oxguard/util',
     'settings!oxguard',
-    'io.ox/core/tk/dialogs', 'gettext!oxguard'
+    'io.ox/core/tk/dialogs',
+    'gettext!oxguard',
+    'less!oxguard/mail/style'
 ], function (ext, og_http, notify, util, settings, dialogs, gt) {
     'use strict';
 
     //#. %s product name
-    var guesticon = '<i id="newguest" class="fa fa-male oxguard_token" style="color:#5DCD55;" title="' + gt('Will create new guest account for %s', window.oxguarddata.productName) + '"/>';
+    var guesticon = '<i id="newguest" class="fa fa-male oxguard_token key_tooltip" style="color:#5DCD55;" data-toggle="tooltip"/>';
     //#. Have encryption key - Shown on icon hover when a key symbol is displayed for recipient.  We/Guard have an encryption key for the recipient.
-    var keyicon = '<i class="fa fa-key oxguard_token oxguard_lock" aria-hidden="true" title="' + gt('Encryption Key Known') +'"></i>';
+    var keyicon = '<i class="fa fa-key oxguard_token key_tooltip" aria-hidden="true" data-toggle="tooltip"></i>';
     //#. %s product name
-    var failicon = '<i id="newguest" class="fa fa-ban oxguard_token" style="color:red;" title="' + gt('Will create new guest account for %s', window.oxguarddata.productName) + '"/>';
+    var failicon = '<i id="newguest" class="fa fa-ban oxguard_token" style="color:red;"/>';
     var prompting = false;
 
     // 7.8 compose code
 
-    function drawKeyIcons(result, location) {
+    function drawKeyIcons(info, location) {
         var input = $(location).parent().find('.token-input');
         var inputwidth = input.width() - 30;
-        switch (result) {
-        case 'pgp' :
-            $(location).find('.close').before(keyicon);
-            break;
-        case 'guest' :
-            $(location).find('.close').before(guesticon);
-            break;
-        case 'fail' :
-            $(location).find('.close').before(failicon);
-            break;
+        var key = $(keyicon);
+        if (info && info.result) {
+            switch (info.result) {
+            case 'pgp' :
+                if (info.key.keySource && info.key.keySource.trusted) {
+                    key.addClass('trusted_key');
+                } else {
+                    key.addClass('untrusted_key');
+                }
+                createTooltip (info.key, key);
+                $(location).find('.close').before(key);
+                break;
+            case 'new' :
+                key.addClass('trusted_key');
+                $(location).find('.close').before(key);
+                createTooltip ('new', key);
+                break;
+            case 'guest' :
+                var gKey = $(guesticon);
+                $(location).find('.close').before(gKey);
+                createTooltip ('guest', gKey);
+                break;
+            case 'fail' :
+                $(location).find('.close').before(failicon);
+
+                break;
+            }
         }
         input.width(inputwidth);
     }
 
+    function createTooltip (data, loc) {
+        require(['oxguard/pgp/keyDetails'], function (pubKeys) {
+            var div = $('<div>');
+            if (data === 'new') {  // New recipient
+                div.append(gt('Key will be created upon sending.'));
+            } else if (data === 'guest') {
+                div.append(gt('Will create new guest account for %s', window.oxguarddata.productName));
+            } else {
+                var detail = pubKeys.keyDetail ([data], true);
+                div = $(detail.div).find('#keyDetail');
+                div.append(gt('Source: ') + getSourceTranslation(data.keySource.name) + '<br/>');
+                div.append(data.keySource.trusted ? gt('Trusted') : gt('Untrusted Source'));
+                div.addClass(data.keySource.trusted ? 'trusted_key' : 'untrusted_key');
+            }
+            $(loc).tooltip({
+                title: div,
+                trigger: 'hover',
+                placement: 'bottom',
+                html: true,
+                delay: 200,
+                animation: true,
+                viewport: { selector: '.io-ox-mail-compose', padding: 10 }
+            });
+        });
+    }
+
+    function getSourceTranslation (source) {
+        switch (source) {
+        case 'HKP_PUBLIC_SERVER':
+            return gt('Public server');
+        case 'HKP_SRV_DNSSEC_SERVER':
+            return gt('Secure DNS referred');
+        case 'HKP_TRUSTED_SERVER':
+            return gt('Trusted server');
+        case 'HKP_SRV_SERVER':
+            return gt('DNS referred');
+        case 'HKP_CACHE':
+            return gt('DNS referred');
+        case 'GUARD_KEY_PAIR':
+            return gt('System key');
+        case 'GUARD_USER_UPLOADED':
+            return gt('Uploaded key');
+        case 'GUARD_USER_SHARED':
+            return gt('Shared key');
+        default:
+            return source;
+        }
+    }
+
     // Return a has of string
     function hash(str) {
         var hashed = 0;
@@ -83,11 +151,13 @@ define('oxguard/mail/oxguard_mail_compose_core', [
         if (_.device('smartphone')) {
             $('.btn-primary:visible').html(gt('Send'));
         } else {
-            var headerview = baton.view.app.get('window').nodes.header;
-            var footerview = baton.view.app.get('window').nodes.footer;
-            headerview.find('.btn-primary:visible').html(gt('Send'));
-            if (footerview) {
-                footerview.find('.btn-primary:visible').html(gt('Send'));
+            if (baton.view.app.get('window')) {
+                var headerview = baton.view.app.get('window').nodes.header;
+                var footerview = baton.view.app.get('window').nodes.footer;
+                headerview.find('.btn-primary:visible').html(gt('Send'));
+                if (footerview) {
+                    footerview.find('.btn-primary:visible').html(gt('Send'));
+                }
             }
         }
         baton.view.$el.find('.oxguard_key').hide();
