@@ -11,27 +11,28 @@ define('oxguard/mail/pin', [
     'io.ox/core/tk/dialogs',
     'oxguard/mail/keymanager',
     'oxguard/mail/mail_metrics',
-    'gettext!oxguard'
+    'gettext!oxguard',
+    'less!oxguard/mail/style'
 ], function (dialogs, keyman, metrics, gt) {
     function showpin (baton) {
         var def = $.Deferred();
         var pin = getpin();
         var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter: 'ok' });
-        dialog.header($('<h4>').text(gt('Security PIN')));
+        dialog.header($('<h4>').text(gt('Advanced Security - PIN')));
         var message = $('<p>');
         var tableMessage = $('<p style="float:left;">' + gt('Recipients:') + '</p>');
-        var table = $('<textarea cols="40" rows="5" style="float:right; padding:5px; margin-right:5%; max-width:90%;"/>');
+        var table = $('<textarea cols="40" rows="3" style="float:right; padding:5px; margin-right:5%; max-width:90%;"/>');
         var names = '';
         (keyman.getGuests(baton)).forEach(function (v) {
             names = names  + v + '\r\n';
         });
         table.text(names);
-        message.append(gt('The new recipients listed below will be sent a password via email.  You can also require a separate pin, which is displayed below.'));
+        message.append(gt('The new recipients listed below will be sent instructions how to read this email.  For additional security, you can assign a PIN that will be used for additional verification.'));
         var pinlabel = $('<label class="pin">' + pin + '</label>');
         var message2 = $('<p>').append(gt('You may deliver this pin any way you see fit, but we recommend doing it in a second method other than email (Phone, SMS, Skype, etc).'));
-        var message3 = $('<p>').append(gt('If you want this extra pin requirement, click OK.'));
+        var message3 = $('<p>').append(gt('If you forget this pin, you can find it in the sent email (requires decrypting).'));
         dialog.getBody().append(message).append(pinlabel).append(message2).append(message3).append('<hr/>').append(tableMessage).append(table);
-        dialog.addPrimaryButton('ok', gt('OK'), 'ok')
+        dialog.addPrimaryButton('ok', gt('Use PIN'), 'ok')
         .addButton('cancel', gt('Skip'), 'cancel')
         .on('ok', function () {
             metrics.track ('guest-pin-added');
