@@ -8,8 +8,7 @@ define('oxguard/mail/register_compose', [
     'io.ox/backbone/mini-views/help',
     'oxguard/mail/keymanager',
     'settings!oxguard',
-    'less!pgp_mail/style',
-    'less!oxguard/style'
+    'less!oxguard/mail/style'
 ], function (ext, gt, Dropdown, core, util, ToggleEncryption, HelpView, keyman, settings) {
     'use strict';
 
@@ -17,7 +16,7 @@ define('oxguard/mail/register_compose', [
 
     ext.point('io.ox/mail/compose/fields').extend({
         id: 'lock',
-        index: 'last',
+        index: 250,
         draw: function (baton) {
             if (!util.hasCryptoCapability()) {
                 // TODO check for encr reply
@@ -29,43 +28,18 @@ define('oxguard/mail/register_compose', [
             });
             view.noLinkMail(baton.view);
             baton.view.toggleEncryption = view;
-            //HACK: always insert first, since we do not control
-            //other content
-            node.prepend(view.render().$el);
+
+            node.append(view.render().$el);
             setupCompose (baton);
         }
     });
 
     function setupCompose (baton) {
 
-        if (util.isMailvelope()) return;
-
         // Check the options for the page.  Lock icon settings, etc
         require (['oxguard/mail/options_new'], function (options) {
             options.createOptions(baton);
         });
-        //register crypto provider choice wizard
-        require(['io.ox/core/capabilities'], function (capabilities) {
-            //skip if no choice is possible
-
-            if (settings.get('cryptoProvider') !== undefined || !capabilities.has('mailvelope && guard')) return;
-
-            baton.model.listenTo(baton.model, 'change:encrypt', function (model, val) {
-                if (val !== true || settings.get('cryptoProvider') !== undefined || !capabilities.has('mailvelope && guard')) return;
-
-                //no setup, yet. do not encrypt
-                model.set('encrypt', false);
-                require(['oxguard/tour/main'], function (registry) {
-                    registry.get('default/oxguard/choice').get('run')().then(function () {
-                        //TODO: remove this "change:encrypt" handler
-                        //setup complete, encrypt!
-                        model.set('encrypt', true);
-                    }, function () {
-                        if (ox.debug) console.log(arguments);
-                    });
-                });
-            });
-        });
     }
 
     // Check if attachment is PGP file, and set email to encrypt if found
@@ -96,18 +70,7 @@ define('oxguard/mail/register_compose', [
         index: 100,
         draw: function (baton) {
             var node = this;
-            if (util.isGuardEnabled()) {
-                drawDropDown (baton, $(node));
-            } else {
-                settings.on('change:cryptoProvider', function () {
-                    if (util.isGuardEnabled()) {
-                        drawDropDown (baton, $(node));
-                        require (['oxguard/mail/options_new'], function (options) {
-                            options.createOptions(baton);
-                        });
-                    }
-                });
-            }
+            drawDropDown (baton, $(node));
         }
     });
 
@@ -116,15 +79,13 @@ define('oxguard/mail/register_compose', [
     ext.point('io.ox/mail/compose/createtoken').extend({
         id: 'guardToken',
         action: function (baton) {
-            if (util.isGuardEnabled()) {
-                if (baton.model.get('encrypt') === true) {
-                    var email = baton.event.attrs.model.get('token').value;
-                    var target = $(baton.event.relatedTarget);
-                    var result = keyman.checkRecips (email, baton);
-                    if (result !== null) {
-                        core.drawKeyIcons(result, target);
-                    }
-                }
+            if (baton.model.get('encrypt') === true) {
+                var email = baton.event.attrs.model.get('token').value;
+                var target = $(baton.event.relatedTarget);
+                keyman.checkRecips (email, baton)
+                .done(function (keyResults) {
+                    core.drawKeyIcons(keyResults[email], target);
+                });
             }
         }
     });
@@ -146,13 +107,13 @@ define('oxguard/mail/register_compose', [
 
     ext.point('io.ox/mail/compose/actions/send').extend({
         id: 'signCheck',
-        index: 601,
+        index: 610,
         perform: function (baton) {
             var def = $.Deferred();
             var security = baton.model.get('security');
             if (security.sign) {
                 require(['oxguard/auth'], function (auth) {
-                    auth.authorize(gt('Please enter your %s password to sign this email.', window.oxguarddata.productName), true)
+                    auth.authorize(baton, gt('Please enter your %s password to sign this email.', window.oxguarddata.productName), true)
                     .done(function (auth) {
                         var security = baton.model.get('security');
                         security.authentication = auth;
@@ -196,7 +157,7 @@ define('oxguard/mail/register_compose', [
                 if ((mimeType && (mimeType.indexOf('pgp-encrypted') > -1)) || (fileName && (fileName.indexOf('.pgp') > -1))) {
                     found = true;
                     require(['oxguard/auth'], function (auth) {
-                        auth.authorize(gt('There appears to be an encrypted attachment.  Please enter your %s password to decode the attachment for sending.', window.oxguarddata.productName), true)
+                        auth.authorize(baton, gt('There appears to be an encrypted attachment.  Please enter your %s password to decode the attachment for sending.', window.oxguarddata.productName), true)
                         .done(function (auth) {
                             security.authentication = auth;
                             baton.model.set('security', security);
@@ -216,7 +177,7 @@ define('oxguard/mail/register_compose', [
     // Check that all keys have been found prior to sending
     ext.point('io.ox/mail/compose/actions/send').extend({
         id: 'keysDoneCheck',
-        index: 750,
+        index: 601,
         perform: function (baton) {
             if (!baton.model.get('encrypt')) return true;
             var def = $.Deferred();
@@ -274,7 +235,7 @@ define('oxguard/mail/register_compose', [
                 var reauthorizing = true,
                 security = baton.model.get('security');
                 require(['oxguard/auth'], function (auth) {
-                    auth.authorize(gt('Please re-enter your %s password.', window.oxguarddata.productName), true, true)
+                    auth.authorize(baton, gt('Please re-enter your %s password.', window.oxguarddata.productName), true, true)
                     .done(function (auth) {
                         if (security) {  // Update security authorization
                             security.authentication = auth;
@@ -325,9 +286,9 @@ define('oxguard/mail/register_compose', [
                 } else {
                     //  Help icon
                     dropdownDiv.find('ul').prepend(new HelpView({
-                        base: 'help-guard',
-                        iconClass: 'guardhelp',
-                        href: 'ox.guard.user.sect.usage.email.send.html',
+                        base: 'help',
+                        iconClass: 'guardhelp fa-question-circle fa',
+                        href: 'ox.appsuite.user.sect.guard.email.send.html',
                         tabindex: '-1'
                     }).render().$el.css('float', 'right').css('margin-right', '10px'));
                     dropdownDiv.css('padding-left', '20px').addClass('security-options');
@@ -342,10 +303,10 @@ define('oxguard/mail/register_compose', [
         var keys = baton.model.get('gkeys');
         var isGuest = false;
         var fail = false;
-        keys.forEach(function (k) {
-            if (k.result === 'guest') isGuest = true;
-            if (k.result === 'fail') fail = true;
-        });
+        for (var email in keys) {
+            if (keys[email].result === 'guest') isGuest = true;
+            if (keys[email].result === 'fail') fail = true;
+        }
         if (fail) {
             require (['io.ox/core/notifications'], function (notifications) {
                 notifications.yell('error', gt('Unable to find keys for all recipients.'));
@@ -374,12 +335,13 @@ define('oxguard/mail/register_compose', [
 
     // Check all keys ready
     function isReady (baton) {
-        function checkKey (key) {
-            return (!key.pending);
-        }
         var keys = baton.model.get('gkeys');
         if (keys === undefined) return true; // No keys
-        return (keys.every(checkKey));
+        var pending = false;
+        for (var email in keys) {
+            pending = pending || keys[email].pending;
+        }
+        return !pending;
     }
 
     // Check if response code and error string contain auth error
@@ -412,7 +374,7 @@ define('oxguard/mail/register_compose', [
         var def = $.Deferred();
         require(['oxguard/auth'], function (auth) {
             var security = baton.model.get('security');
-            auth.authorize(prompt, true, true)  // authorize and force relogin
+            auth.authorize(baton, prompt, true, true)  // authorize and force relogin
             .done(function (auth) {
                 security.authentication = auth;
                 baton.model.set('security', security);
@@ -448,7 +410,7 @@ define('oxguard/mail/register_compose', [
                     def.resolve();
                 }
             }
-        }, 7000);
+        }, 15000);
     }
 
 });
