@@ -11,7 +11,7 @@ define('oxguard/pgp/register', [
     'io.ox/core/extPatterns/links',
     'io.ox/core/extPatterns/actions',
     'oxguard/core/og_http',
-    'oxguard/pgp/checker',
+    'oxguard/mail/checker',
     'io.ox/core/api/account',
     'io.ox/core/capabilities',
     'pgp_mail/util',
@@ -19,12 +19,11 @@ define('oxguard/pgp/register', [
     'io.ox/mail/common-extensions',
     'settings!oxguard',
     'gettext!oxguard',
-    'oxguard/pgp/mailReplyActions'
+    'oxguard/mail/mailReplyActions',
+    'less!oxguard/pgp/style'
 ], function (ext, links, actions, http, checker, account, capabilities, util, metrics, mailExtensions, settings, gt) {
     'use strict';
 
-    // var popupBlockCount = 0;
-
     // Draw security icons in mail detail view
     mailExtensions.security = function (baton) {
         if (!baton.model.get('security')) return;
@@ -62,8 +61,19 @@ define('oxguard/pgp/register', [
             }
             this.append(signedicon);
         }
+        checkIntegrity(baton.data);
     };
 
+    function checkIntegrity (data) {
+        if (data && data.headers) {
+            if (data.headers['X-Guard-Failed-Integrity']) {
+                require(['io.ox/core/notifications'], function (notify) {
+                    notify.yell('warning', gt('This email is missing one or more security checks.  HTML markup was removed for your security.'));
+                });
+            }
+        }
+    }
+
     // Detail View Extensions
     ext.point('io.ox/mail/detail/body').extend({
         id:'guardCheck',
@@ -91,13 +101,12 @@ define('oxguard/pgp/register', [
         id: 'ogPGPCheck',
         index: 1,
         draw: function (baton) {
-            if (util.mailvelopeSelected()) return;
             if (this[0] !== undefined) {
                 var location;
                 if (this[0].host !== undefined) {  // Chrome
                     location = $(this[0].host);
                 } else { // Others
-                    location = this.context.lastChild;
+                    location = this[0];
                 }
                 checker.checkPGP(baton, location);
             }
@@ -111,7 +120,6 @@ define('oxguard/pgp/register', [
         index: 230,
         id: 'ogPGPCheckMobile',
         draw: function (baton) {
-            if (util.mailvelopeSelected()) return;
             var location = this[0];
             checker.checkPGP.call(this, baton, location);
             baton.view.listenTo(baton.view.model, 'change:attachments', function () {
@@ -149,6 +157,16 @@ define('oxguard/pgp/register', [
         }
     });
 
+    ext.point('io.ox/mail/view-options').extend({
+        id: 'guardThread',
+        index: 1,
+        draw: function (baton) {
+            if (capabilities.has('guest')) {
+                baton.app.settings.set('threadSupport', false);
+            }
+        }
+    });
+
     // Methods for actions
     // Check if attachment filename ends with .asc
     function isASC (e) {
@@ -206,7 +224,7 @@ define('oxguard/pgp/register', [
     ext.point('io.ox/mail/detail/attachments').extend({
         id: 'Import',
         draw: function (e) {
-            if (util.mailvelopeSelected()) return;
+            if (capabilities.has('guest')) return;
             var keyfound = false;
             e.attachments.forEach(function (a) {
                 if (testKey(a)) {
@@ -234,7 +252,7 @@ define('oxguard/pgp/register', [
         },
         multiple: function (list) {
             require(['oxguard/auth', 'io.ox/mail/actions/attachmentSave'], function (auth_core, action) {
-                auth_core.authorize(gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
+                auth_core.authorize(list, gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
                 .done(function () {
                     for (var i = 0; i < list.length; i++) {
                         list[i].reEncrypt = true;
@@ -269,10 +287,6 @@ define('oxguard/pgp/register', [
     });
 
     function doImportKey (list) {
-        if (settings.get('cryptoProvider') === 'mailvelope') {
-            loadKeyToMailvelope(list);
-            return;
-        }
         if (window.oxguarddata.passcode === 'No Key') {
             require(['oxguard/core/createKeys'], function (keys) {
                 metrics.track('create-keys-to-import-public');
@@ -351,7 +365,7 @@ define('oxguard/pgp/register', [
             var def = $.Deferred();
             if (baton.data.security && baton.data.security.decrypted) {
                 require(['oxguard/auth'], function (auth_core) {
-                    auth_core.authorize(gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
+                    auth_core.authorize(baton, gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
                     .done(function () {
                         def.resolve();
                     })
@@ -381,10 +395,41 @@ define('oxguard/pgp/register', [
             return;
         }
         baton.stopPropagation(); // Stop this extension and check authorization
+
+        // Local decryption check.  If we decrypted locally, we will have decrypted sessionKey
+        if (baton.data &&
+                (baton.data[0] && baton.data[0].security && baton.data[0].security.sessionKey) ||
+                (baton.data.security && baton.data.security.sessionKey)) {
+            require (['pgp_local/sessionHandler'], function (handler) {
+                var key = _.isArray(baton.data) ? baton.data[0].security.sessionKey : baton.data.security.sessionKey;
+                handler.saveDecryptedSession(key)
+                .done(function () {
+                    validated = true;
+                    baton.resumePropagation();
+                    actions.invoke(extName, array, baton);  // OK, authorized, call the extension again
+                })
+                .fail(function () {
+                    window.setTimeout(function () {
+                        baton.resumePropagation();
+                    }, 500);
+                });
+            });
+            return;
+        }
+
+        // Not local, so authorize against backend
         require(['oxguard/auth', 'io.ox/core/extPatterns/actions'], function (auth_core, actions) {
-            auth_core.authorize(gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
+            auth_core.authorize(baton, gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
             .done(function (authData) {
-                if (baton.data && baton.data[0]) baton.data[0].auth = authData;
+                if (baton.data) {
+                    if (_.isArray(baton.data)) {
+                        baton.data.forEach(function (d) {
+                            d.auth = authData;
+                        });
+                    } else {
+                        baton.data.auth = authData;
+                    }
+                }
                 baton.resumePropagation();
                 validated = true;
                 if (storeAuth) {
@@ -415,6 +460,7 @@ define('oxguard/pgp/register', [
     registerPasswordCheck('io.ox/mail/office/text-edit-asnew');
     registerPasswordCheck('io.ox/mail/office/spreadsheet-edit-asnew');
     registerPasswordCheck('io.ox/mail/actions/vcard');
+    registerPasswordCheck('io.ox/mail/actions/ical');
 
     // Function to check actions for Guard emails, and if found, proper authentication
     function registerPasswordCheck (extName, storeAuth) {
@@ -426,8 +472,8 @@ define('oxguard/pgp/register', [
             },
             multiple: function (array, baton) {
                 if (storeAuth) {
-                    if (util.isEncryptedMail(baton.data) && !util.mailvelopeSelected()) {
-                        baton.data.security = {  // Bug 53624 If encrypted and not yet decrypted, mark to decrypt and auth
+                    if (util.isEncryptedMail(baton.data)) {
+                        baton.data.security = {
                             decrypted: true
                         };
                         doAuthCheck(extName, baton, array, storeAuth);
@@ -462,21 +508,6 @@ define('oxguard/pgp/register', [
     ////////// End extensions
     /// Functions
 
-    // Load keys into mailvelope
-    function loadKeyToMailvelope (list) {
-        require (['mailvelope/main', 'io.ox/mail/api'], function (api, mailAPI) {
-            _(list).each(function (data) {
-                if (testKey(data)) { // make sure key
-                    return $.ajax({ url: mailAPI.getUrl(data, 'view'), dataType: 'text' }).then(function (text) {
-                        api.getKeyring().then(function (keyring) {
-                            keyring.importPublicKey(text);
-                        });
-                    });
-                }
-            });
-        });
-    }
-
     // Save public key from attachment
     function loadPublicKey (list) {
         _(list).each(function (data) {
@@ -488,7 +519,7 @@ define('oxguard/pgp/register', [
                 '&folder=' + data.parent.folder_id;
                 if (data.security && data.security.decrypted) { //If was encrypted
                     require(['oxguard/auth'], function (auth) {
-                        auth.authorize().then(function (auth) {
+                        auth.authorize(list).then(function (auth) {
                             params = params + '&auth=' + encodeURIComponent(auth) +
                             '&inline=' + (data.security.pgpInline ? 'true' : 'false') +
                             '&filename=' + encodeURIComponent(data.filename);
