@@ -29,6 +29,12 @@ define('oxguard/register', [
 
     window.oxguarddata = oxguarddata;
 
+    if (settings.get('pgplocal') === true) {  // Load local keys if set
+        require(['pgp_local/register'], function (pgpLocal) {
+            pgpLocal.loadPrivate();
+        });
+    }
+
     // Load data generated at compile (build version, etc)
     require(['oxguard/oxguard_data'], function (generatedData) {
         _.extend(window.oxguarddata, generatedData);
@@ -43,6 +49,7 @@ define('oxguard/register', [
         settings.save();
     }
 
+    // Sends first login to get settings info, key data
     function sendauth(pass) {
         require (['oxguard/oxguard_core'], function (oxguard) {
             oxguard.auth(ox.user_id, pass)
@@ -53,22 +60,17 @@ define('oxguard/register', [
                         console.debug('Unable to connect to Encryption Server');
                         return;
                     }
-                    oxguarddata = _.extend(window.oxguarddata, data);
+                    oxguarddata = _.extend(window.oxguarddata, checkLanguages(data));
                     oxguarddata.loaded = true;
-                    if (data.auth.length > 20) {// If good code comes back, then store userid
+                    if (data.auth.length > 20 && !(/^Error:/i.test(data.auth))) {// If good code comes back, then store userid
                         oxguarddata.userid = ox.user_id;
                         oxguarddata.passcode = data.auth;
                     } else {// If bad code, then log and mark oxguard.user_id as -1
-                        if ((data.auth.indexOf('Bad') > -1) || (data.auth.indexOf('Lockout') > -1)) {
+                        if (/^((Error)|(Bad)|(Lockout))/i.test(data.auth)) {
                             oxguarddata.passcode = null;
                         } else {
                             oxguarddata.passcode = data.auth;
                         }
-                        if (data.auth !== 'No Key') {
-                            if (settings.get('cryptoProvider') === undefined) {
-                                settings.set('cryptoProvider', 'guard').save();
-                            }
-                        }
                         if (data.error) {
                             require(['io.ox/core/notifications'], function (notify) {
                                 notify.yell('error', productName + '\r\n' + data.error);
@@ -76,6 +78,11 @@ define('oxguard/register', [
                         }
                         oxguarddata.userid = -1;
                     }
+                    if (settings.get('defaultEncrypted') === undefined) {
+                        require(['oxguard/settings/pane'], function (defaults) {
+                            defaults.initSettings(data.settings);
+                        });
+                    }
                     if (ox.context_id === 0) ox.context_id = data.cid; // If the cid wasn't loaded, update from backend
                     oxguarddata.baton = window.oxguarddata.baton;
                     oxguarddata.recovery = data.recoveryAvail === undefined ? !data.noRecovery : data.recoveryAvail;
@@ -115,97 +122,75 @@ define('oxguard/register', [
 
     }
 
-    ext.point('io.ox/core/logout').extend({
-        id: 'logoutOG',
-        index: 1,
-        logout: function () {
-            return doLogout();
+    // Parse out available languages, comparing Guard templates and UI available
+    function checkLanguages (data) {
+        var guardLanguages = data.lang;
+        var available = {};
+        for (var lang in guardLanguages) {
+            if (ox.serverConfig.languages[lang]) {
+                available[lang] = guardLanguages[lang];
+            }
         }
-    });
+        data.lang = available;
+        return data;
+    }
 
     ox.on('relogin:required', function () {
         doLogout();
     });
 
-    function doLogout () {
+    function doLogout (notify) {
         var def = $.Deferred();
-        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&session=' + ox.session;
         window.oxguarddata.passcode = null;
         require (['oxguard/oxguard_core'], function (oxguard) {
             oxguard.saveAuthToSession('', -1)  // destroy auth token
-            .always(function () { // Destroy Guard mapping and auth-token
-                $.get(ox.apiRoot + '/oxguard/login?action=logout' + params, function () {
+            .done(function () { // Destroy Guard mapping and auth-token
+                if (notify) {
                     require(['io.ox/core/notifications'], function (notify) {
                         notify.yell('success', gt('Logged out of %s', productName));
                     });
-                })
-                .fail(function (e) {
-                    require(['io.ox/core/notifications'], function (notify) {
-                        notify.yell('error', gt('Failed to log out of %s', productName));
-                    });
-                    console.log(e);
-                })
-                .always(function () {
-                    def.resolve();
-                });
+                }
             });
         });
 
         return def;
     }
 
-    ext.point('io.ox/core/topbar/right/dropdown').extend({
+    ext.point('io.ox/core/appcontrol/right/dropdown').extend({
         id: 'guard-guided-tour',
         index: 260,
-        draw: function () {
+        extend: function () {
             if (_.device('small')) return;
-
             if (capabilities.has('guard-mail') || capabilities.has('guard-drive')) {
                 this.append(
-                        $('<li class="og_tour">').append(
-                            //#. %s product name
-                            $('<a href="#" data-action="guard-tour" role="menuitem">').text(gt('Guided tour for %s', window.oxguarddata.productName))
-                        )
-                        .on('click', function (e) {
-                            e.preventDefault();
-                            require(['io.ox/core/tk/wizard', 'oxguard/tour/main'], function (Tour) {
-                                Tour.registry.run('default/oxguard');
-                            });
-                        })
-                    );
+                    this.link('GuardTour', gt('Guided tour for %s', window.oxguarddata.productName), function (e) {
+                        e.preventDefault();
+                        require(['io.ox/core/tk/wizard', 'oxguard/tour/main'], function (Tour) {
+                            Tour.registry.run('default/oxguard');
+                        });
+                    })
+                );
             }
         }
     });
 
-    ext.point('io.ox/core/topbar/right/dropdown').extend({
+    ext.point('io.ox/core/appcontrol/right/dropdown/signouts').extend({
         id: 'logoutOG',
-        index: 990,
-        draw: function () {
-            var dropdown = this.parent();
-            dropdown.on('show.bs.dropdown', function () {
+        index: 10,
+        extend: function () {
+            this.link('logoutOG', gt('Sign out %s', window.oxguarddata.productName), function (e) {
+                e.preventDefault();
+                window.oxguarddata.passcode = null;
+                doLogout(true);
+            });
+            this.$el.on('shown.bs.dropdown', function () {
                 var pass = window.oxguarddata.passcode;
                 if (pass && pass.length > 10) {
-                    $('.og_signout').show();
+                    $('[data-name="logoutOG"]').show();
                 } else {
-                    $('.og_signout').hide();
+                    $('[data-name="logoutOG"]').hide();
                 }
             });
-            this.append(
-                $('<li class="divider og_signout" aria-hidden="true" role="presentation"></li>'),
-                $('<li class="og_signout">').append(
-                    //#. %s product name
-                    $('<a href="#" data-action="logout" role="menuitem">').text(gt('Sign out %s', window.oxguarddata.productName))
-                )
-                .on('click', function (e) {
-                    e.preventDefault();
-                    window.oxguarddata.passcode = null;
-                    doLogout();
-                })
-            );
-            var auth = window.oxguarddata.passcode;
-            if (auth === null || auth === undefined) {
-                return;
-            }
         }
     });
 
