@@ -7,7 +7,8 @@ define('oxguard/tour/main', [
     'io.ox/backbone/mini-views/help',
     'oxguard/core/createKeys',
     'settings!oxguard',
-    'gettext!oxguard/tour'
+    'gettext!oxguard/tour',
+    'less!oxguard/tour/style'
 ], function (Tour, hotspot, core, util, capabilities, HelpView, keys, settings, gt) {
     'use strict';
 
@@ -42,9 +43,6 @@ define('oxguard/tour/main', [
         priority: 1
     }, function () {
         if (!util.isGuardConfigured()) {
-            require(['settings!oxguard'], function (settings) {
-                settings.set('cryptoProvider', 'guard').save();
-            });
             Tour.registry.run('default/oxguard/createKeys');
             return;
         }
@@ -59,7 +57,13 @@ define('oxguard/tour/main', [
         } else {
             resetText = gt.format(gt.pgettext('tour', 'You already set up your %s account.  You can change your encryption password here.'), window.oxguarddata.productName);
         }
-
+        // minimze all open windows
+        ox.ui.apps.models.forEach(function (app) {
+            if (app.getWindow() && app.getWindow().floating) {
+                app.getWindow().floating.minimize();
+            }
+        });
+        tour.toggleBackdrop(true);
         tour.step({ labelNext: gt('Next') })
             .title(gt.format(gt.pgettext('tour', 'The %s module'), window.oxguarddata.productName))
             .content(gt.pgettext('tour', 'Security and privacy matters to everyone. That\'s why you can now send and receive encrypted emails by simply clicking on the lock icon.'))
@@ -84,9 +88,6 @@ define('oxguard/tour/main', [
                     ox.ui.App.reuse(composeApp.cid);
                 }
             })
-            .on('next', function () {
-                composeApp.view.$el.find('.toggle-encryption .fa').click();
-            })
             .end();
         tour.once('stop', function () {
             if (composeApp && composeApp.model) {
@@ -102,68 +103,61 @@ define('oxguard/tour/main', [
             .title(gt.format(gt.pgettext('tour', '%s Security Settings'), window.oxguarddata.productName))
             .content(resetText)
             .on('wait', function () {
+                composeApp.getWindow().floating.minimize();  // Minimize the floating window
                 ox.launch('io.ox/settings/main', { id: 'oxguard' }).then(function () {
                     this.setSettingsPane({ id: 'oxguard' });
                 });
             })
-            .waitFor('.oxguard_settings.password')
-            .spotlight('.oxguard_settings.password')
-            .on('ready', function () {
-                $('.oxguard_settings').css('padding', '10px');
-            })
+            .waitFor('#passwordDiv')
+            .referTo('#passwordDiv')
+            .spotlight('#passwordDiv', { 'padding': 10 })
             .end()
         .step()
             .title((settings.get('advanced') ? gt.pgettext('tour', 'PGP Encryption Settings') : gt.pgettext('tour', 'Security Settings')))
             .content((settings.get('advanced') ?
                     gt.pgettext('tour', 'From here you can update your encryption settings. For example you can choose to send encrypted emails by default.') :
                     gt.pgettext('tour', 'From here, you can update your security settings.  For example, you can choose to send secure emails by default.')))
-            .on('wait', function () {
-                ox.launch('io.ox/settings/main', { id: 'oxguard/pgp' }).then(function () {
-                    this.setSettingsPane({ id: 'oxguard/pgp' });
-                });
-            })
-            .waitFor('.oxguard_settings.defaults')
-            .spotlight('.oxguard_settings.defaults')
-            .hotspot('.oxguard_settings.defaults #pgpdefault', { 'top': 5, 'left': 5 })
-            .on('ready', function () {
-                $('.oxguard_settings').css('padding', '10px');
-            })
+            .waitFor('.guardDefaults')
+            .spotlight('.guardDefaults', { 'padding': 10 })
+            .hotspot('.guardDefaults [name="defaultEncrypted"]', { 'top': 7, 'left': 7 })
             .end()
         .step()
             .title(gt.pgettext('tour', 'Signature'))
             .content(gt.pgettext('tour', 'In addition to encrypting your emails you can also sign them. This means that email recipients can be sure that the email really came from you. By ticking this checkbox your signature will be added to outgoing emails by default.'))
-            .on('wait', function () {
-                ox.launch('io.ox/settings/main', { id: 'oxguard/pgp' }).then(function () {
-                    this.setSettingsPane({ id: 'oxguard/pgp' });
-                });
-            })
-            .waitFor('.oxguard_settings.defaults')
-            .spotlight('.oxguard_settings.defaults')
-            .hotspot('.oxguard_settings.defaults #pgpsign', { 'top': 5, 'left': 5 })
+            .waitFor('.guardDefaults')
+            .spotlight('.guardDefaults', { 'padding': 10 })
+            .hotspot('.guardDefaults [name="defaultSign"]', { 'top': 7, 'left': 7 })
             .end();
         if (settings.get('advanced')) {
             tour.step()
             .title(gt.pgettext('tour', 'Alternative: PGP Inline'))
             .content(gt.format(gt.pgettext('tour', 'By default %s sends encrypted emails using PGP/Mime format. To communicate with some systems you may need to use PGP Inline.'), window.oxguarddata.productName))
-            .on('wait', function () {
-                ox.launch('io.ox/settings/main', { id: 'oxguard/pgp' }).then(function () {
-                    this.setSettingsPane({ id: 'oxguard/pgp' });
-                });
-            })
-            .waitFor('.oxguard_settings.defaults')
-            .spotlight('.oxguard_settings.defaults')
-            .hotspot('.oxguard_settings.defaults #inlinedefault', { 'top': 5, 'left': 5 })
+            .waitFor('.guardDefaults')
+            .spotlight('.guardDefaults', { 'padding': 10 })
+            .hotspot('.guardDefaults [name="defaultInline"]', { 'top': 7, 'left': 7 })
             .end()
             .step()
             .title(gt.pgettext('tour', 'Advanced Settings'))
-            .content(gt.pgettext('tour', 'Advanced users can manage their key lists from the PGP Encryption Settings.'))
+            //#. Part of the tour, showing where to manage recipient public keys
+            .content(gt.pgettext('tour', 'Here you can manage PGP Public keys for your recipients.'))
+            .waitFor('.scrollDone') // hack for waiting for scoll to finish
+            .spotlight('.guardAdvanced [name="recipients"]', { 'padding': 10 })
             .on('wait', function () {
-                ox.launch('io.ox/settings/main', { id: 'oxguard/pgp' }).then(function () {
-                    this.setSettingsPane({ id: 'oxguard/pgp' });
+                $('.settings-detail-pane').animate({ scrollTop: $('.guardAdvanced [name="recipients"]').offset().top }, 400, function () {
+                    $('.guardAdvanced [name="recipients"]').addClass('scrollDone');
                 });
             })
-            .waitFor('.oxguard_settings.keys')
-            .spotlight('.oxguard_settings.keys')
+            .on('show', function () {
+                $('.guardAdvanced [name="recipients"]').removeClass('scrollDone');
+            })
+            .end()
+            .step()
+            .title(gt.pgettext('tour', 'Advanced Settings'))
+            //#. Part of the tour, showing where you can manage your private keys
+            .content(gt.pgettext('tour', 'Users can manage their private keys here.'))
+            .spotlight('.guardAdvanced [name="yourKeys"]', { 'padding': 10 })
+            .on('show', function () {
+            })
             .end();
         } else {
             tour
@@ -172,9 +166,10 @@ define('oxguard/tour/main', [
             .content($('<div>').append(
                     $('<p>').text(gt.pgettext('tour', 'Enabling Advanced PGP Features will enable key management and specifying sending formats.'))
              ))
-             .waitFor('.pgpadvanced')
-             .hotspot('.pgpadvanced', { 'top': 5, 'left': 5 })
-             .spotlight('.selectable.pgpadvanced')
+             .waitFor('[name="advanced"]')
+             .hotspot('[name="advanced"]', { 'top': 7, 'left': 7 })
+             .referTo($('[name="advanced"]').parent())
+             .spotlight($('[name="advanced"]').parent(), { 'padding': 10 })
              .end();
         }
         tour
@@ -186,13 +181,22 @@ define('oxguard/tour/main', [
             ))
             .on('wait', function () {
                 ox.ui.App.reuse(composeApp.cid);
+                composeApp.getWindow().floating.toggle();
+
                 window.setTimeout(function () {
-                    hotspot.add('.toggle-encryption', { 'top': 14, 'left': 14 });
+                    hotspot.add('.toggle-encryption', { 'top': 14, 'left': 7 });
                     composeApp.model.set('encrypt', false);
                 }, 500);
             })
             .hotspot(['#statuslock'])
             .waitFor('.toggle-encryption .fa')
+            .on('next', function () {
+                if (composeApp && composeApp.model) {
+                    //prevent app from asking about changed content
+                    composeApp.model.dirty(false);
+                    composeApp.quit();
+                }
+            })
             .end();
         if (capabilities.has('guard-drive')) {
             tour.step()
@@ -210,7 +214,7 @@ define('oxguard/tour/main', [
                     }, 500);
                 }, 500);
             })
-            .on('hide', function () {
+            .on('next', function () {
                 $('.classic-toolbar [data-action=more] ~ ul').css('display', '');
             })
             .end();
@@ -220,14 +224,16 @@ define('oxguard/tour/main', [
         .step()
             .title(gt.pgettext('tour', 'Restart Guided Tour'))
             .content(gt.pgettext('tour', '<em>Hint:</em> you can start guided tours, any time you need them, from the system menu.'))
-            .hotspot('[data-action="guard-tour"]', { 'top': 13, 'left': 10 })
+            .hotspot('[data-name="GuardTour"]', { 'top': 13, 'left': 10 })
             .referTo('#topbar-settings-dropdown')
             .waitFor('#topbar-settings-dropdown')
             .on('wait', function () {
-                $('#topbar-settings-dropdown').css('display', 'block');
+                $('#io-ox-topbar-dropdown-icon').find('.dropdown-toggle').click();
             })
-            .on('hide', function () {
-                $('#topbar-settings-dropdown').css('display', '');
+            .on('next', function () {
+                if ($('#topbar-settings-dropdown').css('display') === 'block') {
+                    $('#io-ox-topbar-dropdown-icon').find('.dropdown-toggle').click();
+                }
             })
             .end()
         .step()
@@ -244,7 +250,7 @@ define('oxguard/tour/main', [
                 $('<p>').append($('<a href="#">').click(setEncryptDefault).text(gt.pgettext('tour', 'Activate encryption for all new emails'))),
                 $('<p>').append($('<a href="#">').click(openSettings).text(gt.pgettext('tour', 'Review your encryption settings'))),
                 $('<p class="help">').append(new HelpView({
-                    base: 'help-guard',
+                    base: 'help',
                     content: gt.pgettext('tour', 'Learn more')
                 }).render().$el)
             ))
@@ -335,13 +341,13 @@ define('oxguard/tour/main', [
             .content($('<div>').append(
                 $('<p>').text(gt.format(gt.pgettext('tour', 'Congratulations, you have successfully setup %s'), window.oxguarddata.productName)),
                 $('<p>').text(gt.format(gt.pgettext('tour', 'Now you can learn more about how to use %s by following the links below:'), window.oxguarddata.productName)),
-                $('<p>').append($('<a href="#">').click(function () {
+                $('<p>').append($('<a id="startTourLink" href="#">').click(function () {
                     $('.wizard-step .btn-primary').click();
                     Tour.registry.run('default/oxguard');
                     //#. %s product name
                 }).text(gt('Guided tour for %s', window.oxguarddata.productName))),
                 $('<p>').append(new HelpView({
-                    base: 'help-guard',
+                    base: 'help',
                     content: gt.format(gt.pgettext('tour', 'Learn more about %s'), window.oxguarddata.productName)
                 }).render().$el)
             ))
@@ -361,66 +367,5 @@ define('oxguard/tour/main', [
         return def;
     });
 
-    Tour.registry.add({
-        id: 'default/oxguard/choice',
-        priority: 1
-    }, function () {
-        return require(['settings!oxguard', 'oxguard/tour/choice', 'mailvelope/main'])
-        .then(function (settings, Choice, api) {
-
-            var def = $.Deferred();
-
-            if (settings.get('cryptoProvider') !== undefined) {
-                def.resolve(settings.get('cryptoProvider'));
-                return def;
-            } else if (api.isMailvelopeSupported() && (capabilities.has('forceMailvelope') || !capabilities.has('guard-mail'))) {
-                settings.set('cryptoProvider', 'mailvelope').save();
-                def.resolve('mailvelope');
-                return (def);
-            }
-
-            var model = settings.createModel(Backbone.Model);
-            new Tour().step()
-                .title(gt('Choose your security solution'))
-                .content(new Choice.View({
-                    model: model
-                }).render().$el)
-                .beforeShow(function () {
-                    var tour = this;
-                    this.$el.addClass('choice_wizard');
-
-                    this.$('[data-action="back"]').hide();
-                    this.$('[data-action="next"]').hide();
-                    this.$('[data-action="done"]').hide();
-
-                    model.on('change:cryptoProvider', function (model, provider) {
-                        settings.set('cryptoProvider', model.get('cryptoProvider'));
-                        settings.save();
-                        def.resolve(provider);
-                        tour.trigger('done');
-                    });
-                })
-                .end()
-            .on('stop', function () {
-                if (def.state() === 'pending' && settings.get('cryptoProvider') === undefined) def.reject('incomplete');
-            })
-            .start();
-
-            return def;
-        }).then(function (provider) {
-            //FIXME: unify calls via Tour.registry API. if's are bad
-            if (provider === 'guard') {
-                return Tour.registry.get('default/oxguard/createKeys').get('run')();
-            }
-            if (provider === 'mailvelope') {
-                return require(['mailvelope/tour']).then(function (runTour) {
-                    return runTour();
-                });
-            }
-
-            return provider;
-        });
-    });
-
     return Tour.registry;
 });
