@@ -1,13 +1,14 @@
 define('pgp_mail/toggle-encryption', [
-    'mailvelope/main',
     'io.ox/core/capabilities',
     'gettext!oxguard',
-    'settings!oxguard'
-], function (api, capabilities, gt, settings) {
+    'settings!oxguard',
+    'less!pgp_mail/style'
+], function (capabilities, gt, settings) {
 
     'use strict';
 
     var ToggleEncryptionView = Backbone.View.extend({
+        tagName: 'button',
         initialize: function () {
             this.listenTo(this.model, 'change:encrypt', function (model, val) {
                 this.$('i.fa').toggleClass('encrypted', val);
@@ -17,7 +18,7 @@ define('pgp_mail/toggle-encryption', [
         },
         className: 'toggle-encryption',
         events: {
-            'click i.fa': 'toggle',
+            'click': 'toggle',
             'change:encrypt': 'changed'
         },
         toggle: function () {
@@ -41,34 +42,42 @@ define('pgp_mail/toggle-encryption', [
                     guard = (window.oxguarddata.settings.oxguard === true);
                 }
             }
-            if (api.isMailvelopeSupported() || guard || this.encryption_forced)
+            if (guard || this.encryption_forced)
                 {
-                if (!_.device('small'))
-                this.$el.empty().append(
-                    $('<i class="fa fa-2x">')
-                    .toggleClass('encrypted', !!this.model.get('encrypt'))
-                );
-            }
-            if (_.device('small')) {
-                this.$el.addClass('mobile-toggle');
+                if (!_.device('small')) {
+                    this.$el.empty().append(
+                            $('<i class="fa fa-2x" aria-hidden="true">')
+                            .toggleClass('encrypted', !!this.model.get('encrypt'))
+                        );
+                    this.$el.attr('title', gt('Enable Encryption'));
+                }
             }
             this.listenTo(this.model, 'change:encrypt', function () {
                 this.changed();
             });
+            if (this.model.get('encrypt')) {
+                var view = this.view;
+                window.setTimeout(function () {
+                    showAttLink(view, false);
+                }, 100);
+            }
             return this;
         },
         noLinkMail: function (view) {
             this.view = view;
             checkAttLink (this.model, view);
-            stopAttLink();
         },
         changed: function () {
+            var security = _.extend({}, this.model.get('security'));
+            security.encrypt = this.model.get('encrypt');
+            this.model.set('security', security);
+            this.$el.attr('title', security.encrypt ? gt('Disable Encryption') : gt('Enable Encryption'));
             if (this.model && this.model.get('encrypt')) {
                 showAttLink(this.view, false);
                 checkAttLink(this.model);
                 try {
                     var fromArray = this.model.get('from');
-                    if (window.oxguarddata.primaryEmail !== undefined) {
+                    if (fromArray && window.oxguarddata.primaryEmail !== undefined) {
                         if (window.oxguarddata.primaryEmail !== fromArray[0][1]) {
                             var warn = settings.get('warnEmailDifferent');
                             if (warn === undefined || warn === false) {
@@ -85,37 +94,10 @@ define('pgp_mail/toggle-encryption', [
         }
     });
 
-    // We need to disable the mail attachment link if encryption set
-    function stopAttLink () {
-        require (['io.ox/core/extPatterns/links'], function (links) {
-            new links.Action('io.ox/mail/compose/attachment/shareAttachmentsEnable', {
-                id: 'stop',
-                index: 1,
-                requires: function (e) {
-                    try {
-                        if (e.baton.view.model.get('encrypt')) {  // Do not offer shareAttachments if encrypted
-                            console.log('stopping');
-                            e.stopPropagation();
-                            return false;
-                        }
-                    } catch (f) {
-                        console.log(f);
-                    }
-                    return false;
-                }
-            });
-        });
-    }
-
     // Hide or show mail attachment link
     function showAttLink (view, show) {
         if (view) {
-            if (show) {
-                view.$el.find('.links.shareAttachments').show();
-            } else {
-                view.$el.find('.links.shareAttachments').hide();
-            }
-
+            view.$el.find('.share-attachments').toggleClass('guardDisabled', !show);
         }
     }
 
@@ -124,7 +106,7 @@ define('pgp_mail/toggle-encryption', [
         if (model.get('share_attachments')) {
             if (model.get('share_attachments').enable) {
                 if (model.get('encrypt')) {
-                    showAttLink(view,false);
+                    showAttLink(view, false);
                 }
             }
         }
@@ -141,6 +123,12 @@ define('pgp_mail/toggle-encryption', [
                     dialog.getBody().append(text);
                     dialog
                     .addPrimaryButton('ok', gt('OK'), 'ok')
+                    .on('ok', function () {
+                        $('.share-attachments').find(':checkbox').prop('checked', false);
+                        var share = model.get('share_attachments');
+                        share.enable = false;
+                        model.set('share_attachments', share);
+                    })
                     .show();
                 });
             }
