@@ -6,13 +6,7 @@ define('pgp_mail/util', [
 ], function (util, capabilities, settings, lib) {
     'use strict';
 
-    function mailvelopeSelected () {
-        return settings.get('cryptoProvider') === 'mailvelope';
-    }
-
     function isEncryptEnabled () {
-        if (mailvelopeSelected ()) return true;
-        if (capabilities.has('mailvelope') && settings.get('cryptoProvider') === undefined) return true; // True for not setup mailvelope
         if (window.oxguarddata && (window.oxguarddata.settings.oxguard || window.oxguarddata.action === 'secureReply')) return true;
         return false;
     }
@@ -84,7 +78,6 @@ define('pgp_mail/util', [
         isSignedMail: isSigned,
         getPGPInfo: getPGPInfo,
         isEncryptEnabled: isEncryptEnabled,
-        mailvelopeSelected: mailvelopeSelected,
         builder: {
             fromModel: buildFromModel
         }
