@@ -12,6 +12,8 @@ Object.keys(window.__karma__.files).forEach(function(file) {
     allTestFiles.push(pathToModule(file));
   }
 });
+localStorage.clear();
+window.oxguarddata = { productName: 'Guard' };
 
 require(['io.ox/core/extPatterns/stage'], function (Stage) {
 
